# Tom Collins and Adrián Barahona-Ríos, 25/10/2022
# Adapted from https://www.r-bloggers.com/2022/05/two-way-anova-example-in-r-quick-guide/

# Dependencies
library("ggpubr")
library("dplyr")
library("multcomp")

# User selection
# Load listening study participant data and melody features.
loss.data <- read.csv("models_loss.csv", header=TRUE)


# Show first few rows and structure of data.
head(loss.data)
str(loss.data)

# Compute ANOVA.
res.aov <- aov(loss ~ model*sfx, data = loss.data)
summary(res.aov)

# Compute pairwise-comparisons.
TukeyHSD(res.aov, which = c("model", "sfx"))
pc.model <- pairwise.t.test(
  loss.data$loss, loss.data$model,
  p.adjust.method = "bonferroni"
)
pc.sfx <- pairwise.t.test(
  loss.data$loss, loss.data$sfx,
  p.adjust.method = "bonferroni"
)
# Or
res.aov2 <- aov(loss ~ model + sfx, data = loss.data)
summary(glht(res.aov2), linfct = mcp(model = "Tukey"))

# Look at group means and SDs.
group_by(loss.data, model, sfx) %>%
summarise(
  count = n(),
  mean = mean(loss, na.rm = TRUE),
  sd = sd(loss, na.rm = TRUE)
)

# A couple of plots
boxplot(
  loss ~ model*sfx, data = loss.data, frame = FALSE,
  col = c("#00AFBB", "#E7B800", "#D9345D", "#000000", "#888888"),
  ylab = "Loss"
)

interaction.plot(
  x.factor = loss.data$model,
  trace.factor = loss.data$sfx,
  response = loss.data$loss, fun = mean,
  type = "b", legend = TRUE,
  xlab = "Model", ylab = "Loss",
  pch=c(1,19),
  col = c("#00AFBB", "#E7B800", "#D9345D", "#13A11D")
)

